10010 - Resource Invalid — fantastico 0.5.0-b126 documentation

### Navigation

- index
- next |
- previous |
- fantastico 0.5.0-b126 documentation »
- Fantastico features »
- ROA (Resource Oriented Architecture) »
- ROA Technical Summary »

# 10010 - Resource Invalid

Whenever a resource is created / updated a validation is done using a custom validator (ROA (Resource Oriented Architecture)). You can find below a sample example of error message you might receive:

    {"error_code": 10010,
     "error_description": "Friendly error description.",
     "error_details": <link to this page>}

### Navigation

- index
- next |
- previous |
- fantastico 0.5.0-b126 documentation »
- Fantastico features »
- ROA (Resource Oriented Architecture) »
- ROA Technical Summary »